@@ -1,36 +1,37 @@
 package Resque;
-$Resque::VERSION = '0.19';
+# ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
+$Resque::VERSION = '0.20';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
+use Class::Load;
 use Data::Compare;
 with 'Resque::Pluggable';
 
-# ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-
-use Redis;
 use Resque::Job;
 use Resque::Worker;
 use Resque::Failures;
 
+sub _redis_class{ Class::Load::load_first_existing_class( 'Redis::Fast', 'Redis' ) }
 
-subtype 'Sugar::Redis'
-    => as class_type('Redis');
-coerce 'Sugar::Redis'
-    => from 'Str'
-    => via { Redis->new(
+
+
+subtype 'Sugar::Redis' => as 'Object';
+coerce 'Sugar::Redis' => from 'Str' => via {
+    _redis_class->new(
         server    => $_,
         reconnect => 60,
         every     => 250,
         encoding  => undef
-    )};
+    )
+};
 
 has redis => (
     is      => 'ro',
     lazy    => 1,
     coerce  => 1,
     isa     => 'Sugar::Redis',
-    default => sub { Redis->new }
+    default => sub { _redis_class->new }
 );
 
 has namespace => ( is => 'rw', default => sub { 'resque' } );
@@ -176,7 +177,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -241,9 +242,9 @@ A lot more about Resque can be read on the original blog post: L<http://github.c
 
 =head2 redis
 
-Redis instance for this Resque instance.
-Accept a Redis object or string. When a string is
-passed in, it will be used as Redis server argument.
+Redis instance for this Resque instance. Accepts a string, L<Redis>, L<Redis::Fast> or any other object that behaves like those.
+
+When a string is passed in, it will be used as the server argument of the auto selected driver wich.
 
 =head2 namespace
 
